@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #    Copyright 2013 Red Hat, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -284,6 +285,9 @@ class TestUUID(TestField):
             ('da66a411-af0e-4829-9b67-475017ddz152',
                 'da66a411-af0e-4829-9b67-475017ddz152'),
             ('fake_uuid', 'fake_uuid'),
+            (u'fake_uāid', u'fake_uāid'),
+            (b'fake_u\xe1id'.decode('latin_1'),
+                b'fake_u\xe1id'.decode('latin_1')),
             ('1', '1'),
             (1, '1')
         ]
@@ -359,11 +363,11 @@ class TestEnum(TestField):
         self.assertRaises(ValueError, self.field.stringify, '123')
 
     def test_fieldtype_get_schema(self):
-        self.assertEqual({'enum': ["foo", "bar", 1, True]},
+        self.assertEqual({'type': ['string'], 'enum': ["foo", "bar", 1, True]},
                          self.field._type.get_schema())
 
     def test_get_schema(self):
-        self.assertEqual({'enum': ["foo", "bar", 1, True],
+        self.assertEqual({'type': ['string'], 'enum': ["foo", "bar", 1, True],
                           'readonly': False}, self.field.get_schema())
 
     def test_fingerprint(self):
@@ -560,7 +564,7 @@ class TestFlexibleBoolean(TestField):
 class TestDateTime(TestField):
     def setUp(self):
         super(TestDateTime, self).setUp()
-        self.dt = datetime.datetime(1955, 11, 5, tzinfo=iso8601.iso8601.Utc())
+        self.dt = datetime.datetime(1955, 11, 5, tzinfo=iso8601.iso8601.UTC)
         self.field = fields.DateTimeField()
         self.coerce_good_values = [(self.dt, self.dt),
                                    (_utils.isotime(self.dt), self.dt)]
@@ -573,7 +577,7 @@ class TestDateTime(TestField):
             '1955-11-05T18:00:00Z',
             self.field.stringify(
                 datetime.datetime(1955, 11, 5, 18, 0, 0,
-                                  tzinfo=iso8601.iso8601.Utc())))
+                                  tzinfo=iso8601.iso8601.UTC)))
 
     def test_get_schema(self):
         self.assertEqual({'type': ['string'], 'format': 'date-time',
@@ -911,7 +915,7 @@ class TestObject(TestField):
         class TestFoo(TestFakeObject, obj_base.ComparableVersionedObject):
             fields = {
                 'name': fields.StringField(),
-                'bar': fields.ObjectField('TestBar')
+                'bar': fields.ObjectField('TestBar', nullable=True)
             }
 
         bar = TestBar(name='bar')
@@ -978,6 +982,12 @@ class TestObject(TestField):
                           "TestAnimal", "VersionedObject"],
                          fields.Object._get_all_obj_names(babe))
 
+        # When stringifying we should see the subclass object name
+        # not the base class object name
+        self.assertEqual("TestDog", animals.stringify(wolfy))
+        self.assertEqual("TestCrocodile", animals.stringify(ticktock))
+        self.assertEqual("TestPig", animals.stringify(babe))
+
         # Everything is an animal
         self.assertEqual(wolfy, animals.coerce(None, "animal", wolfy))
         self.assertEqual(ticktock, animals.coerce(None, "animal", ticktock))
@@ -1041,7 +1051,7 @@ class TestObject(TestField):
                              'versioned_object.name',
                              'versioned_object.version',
                              'versioned_object.data'],
-                'type': 'object'
+                'type': ['object']
             },
             self.field.get_schema())
 
